@@ -34,20 +34,43 @@ class PaymentCallbackForm(forms.ModelForm):
 
     class Meta:
         model = Payment
-        fields = ('transaction_id', 'testing', 'amount', 'currency',
-                  'order_id', 'state', 'message', 'meta')
+        fields = (
+            'transaction_id',
+            'testing',
+            'amount',
+            'currency',
+            'order_id',
+            'state',
+            'message',
+            'meta',
+        )
 
 
 class PaymentForm(forms.Form):
     MAX_DESCRIPTION_LENGTH = 250
 
     @classmethod
-    def create(cls, request, amount, order_id, description,
-               client_email='', client_phone='', client_name='',
-               meta=None, cancel_url=None):
-        cancel_url = request.build_absolute_uri(cancel_url) \
-            if cancel_url is not None and not cancel_url.startswith(('http://', 'https://')) else cancel_url
+    def create(
+        cls,
+        request,
+        amount,
+        order_id,
+        description,
+        client_email='',
+        client_phone='',
+        client_name='',
+        meta=None,
+        cancel_url=None,
+        testing=None,
+    ):
+        if cancel_url is not None and not cancel_url.lower().startswith(('http://', 'https://')):
+            cancel_url = request.build_absolute_uri(cancel_url)
+
+        if testing is None:
+            testing = config.FUTUPAYMENTS_TEST_MODE
+
         data = {
+            'testing': str(int(testing)),
             'amount': amount,
             'description': description[:cls.MAX_DESCRIPTION_LENGTH],
             'order_id': str(order_id),
@@ -79,10 +102,11 @@ class PaymentForm(forms.Form):
         key = config.FUTUPAYMENTS_SECRET_KEY
         data['signature'] = get_signature(key, data)
         form = cls(data)
-        form.action = config.FUTUPAYMENTS_URL
+        form.action = config.FUTUPAYMENTS_HOST + '/pay'
         assert form.is_valid(), form.as_p()
         return form
 
+    testing = forms.CharField(widget=forms.HiddenInput)
     merchant = forms.CharField(widget=forms.HiddenInput)
     amount = forms.DecimalField(widget=forms.HiddenInput)
     currency = forms.CharField(widget=forms.HiddenInput)
